@@ -1,8 +1,6 @@
 OC.L10N.register(
     "news",
     {
-    "Can not add feed: Exists already" : "لا يمكن اضافة هذا الملقم:هو موجود بالفعل",
-    "Articles without feed" : "مقالات بدون ملقم",
     "News" : "الأخبار",
     "Saved" : "حفظ",
     "Download" : "تنزيل",
