@@ -28,8 +28,8 @@ OC.L10N.register(
     "No articles available" : "Artikkeleita ei ole saatavilla",
     "No unread articles available" : "Lukemattomia artikkeleita ei ole saatavilla",
     "Open website" : "Avaa verkkosivu",
-    "Star article" : "Merkitse artikkeli tähdellä",
-    "Unstar article" : "Poista artikkelin tähtimerkintä",
+    "Star article" : "Lisää artikkeli suosikkeihin",
+    "Unstar article" : "Poista artikkeli suosikeista",
     "Keep article unread" : "Pidä artikkeli lukemattomana",
     "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
     "by" : "Kirjoittaja:",
@@ -43,8 +43,8 @@ OC.L10N.register(
     "Jump to next article" : "Siirry seuraavaan artikkeliin",
     "left" : "vasen",
     "Jump to previous article" : "Siirry edelliseen artikkeliin",
-    "Toggle star article" : "Aseta tähti/poista tähti",
-    "Star article and jump to next one" : "Aseta tähti artikkelille ja siirry seuraavaan",
+    "Toggle star article" : "Suosikkimerkintä päälle/pois",
+    "Star article and jump to next one" : "Lisää artikkeli suosikkeihin ja siirry seuraavaan",
     "Toggle keep current article unread" : "Pidä lukemattomana/aseta luetuksi",
     "Open article in new tab" : "Avaa artikkeli uudessa välilehdessä",
     "Toggle expand article in compact view" : "Laajenna artikkeli tiivissä näkymässä/supista artikkeli",
@@ -93,7 +93,7 @@ OC.L10N.register(
     "Collapse" : "Kutista näkymää",
     "Deleted folder" : "Kansio poistettu",
     "Undo delete folder" : "Kumoa kansion poistaminen",
-    "Starred" : "Suositut",
+    "Starred" : "Suosikit",
     "Unread articles" : "Lukemattomat artikkelit",
     "All articles" : "Kaikki artikkelit",
     "Settings" : "Asetukset",
@@ -106,7 +106,7 @@ OC.L10N.register(
     "Export" : "Vie",
     "Error when importing: File does not contain valid OPML" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista OPML:ää",
     "Error when importing: OPML is does neither contain feeds nor folders" : "Virhe tuotaessa: OPML ei sisällä syötteitä tai kansioita",
-    "Unread/Starred Articles" : "Lukemattomat/tähdellä varustetut artikkelit",
+    "Unread/Starred Articles" : "Suosikit ja lukemattomat artikkelit",
     "Error when importing: file does not contain valid JSON" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista JSONia",
     "Help" : "Ohje",
     "Keyboard shortcuts" : "Pikanäppäimet",
