@@ -7,25 +7,27 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Žeton je pretekel ali pa program ni omogočen! Poskusite osvežiti stran!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Notranja napaka strežnika! Preverite datoteko data/nextcloud.log za podrobnosti!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva je spodletela! Okolje Nextcloud je trenutno v vzdrževalnem načinu!",
-    "Can not add feed: Unable to parse feed" : "Vira ni mogoče dodati: podatkov ni mogoče razčleniti",
-    "Can not add feed: Exists already" : "Vira ni mogoče dodati: vir že obstaja",
-    "Articles without feed" : "Prispevki brez virov",
     "News" : "Novice",
     "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
     "Use system cron for updates" : "Za posodobitve uporabi sistemski program »cron«",
+    "Disable this if you run a custom updater such as the Python updater included in the app." : "Možnost onemogočite, če uporabljate posodabljalnik po meri, kot je na primer posodabljalnik Python, vključen v programski paket.",
     "Purge interval" : "Časovni razmik odstranjevanja",
+    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Najkrajši čas, po katerem bodo viri in mape odstranjeni iz podatkovne zbirke. Vrednosti pod 60 sekundami so prezrte.",
     "Maximum read count per feed" : "Največje število prikazanih virov",
+    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Določa največje število prispevkov vira, ki bodo ostali vidni po čiščenju zgodovine. Če se pojavljajo starejši prispevki, je določilo nastavljeno prenizko. Vrednost -1 onemogoči izvajanje možnosti.",
     "Maximum redirects" : "Največje število preusmeritev",
     "How many redirects the feed fetcher should follow." : "Koliko preusmeritvam naj sledi bralnik virov",
     "Feed fetcher timeout" : "Čas nalaganja vira",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Čas, namenjen nalaganju virov RSS in Atom. Če traja dlje je nalaganje virov prekinjeno.",
     "Explore Service URL" : "Razišči spletni naslov storitve",
+    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Če je podan, bo prek tega naslova URL storitve potekala poizvedba za vire in njihov izbor. Za preklop v vgrajeno storitev določevanja, mora biti polje prazno.",
     "For more information check the wiki." : "Za več podrobnosti obiščite Wiki",
     "Update interval" : "Razmik posodobitev",
     "Interval in seconds in which the feeds will be updated." : "Časovni zamik v sekundah za posodabljanje spletnih virov.",
     "Saved" : "Shranjeno",
     "Download" : "Prejmi",
     "Close" : "Zapri",
+    "Subscribe to" : "Naročnina na",
     "No articles available" : "Ni prispevkov",
     "No unread articles available" : "Ni neprebranih prispevkov",
     "Open website" : "Odpri spletišče",
