@@ -7,9 +7,6 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Polletten föråldrad eller så är applikationen inte aktiverad! Uppdatera sidan.",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internt serverfel! Vänligen kontrollera din loggfil under data/nextcloud.log för mer information!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Förfrågan misslyckades. Nextcloud är för närvarande i underhållsläge!",
-    "Can not add feed: Unable to parse feed" : "Kan inte lägga till flöde: Går inte att läsa flöde",
-    "Can not add feed: Exists already" : "Kan inte lägga till: flödet existerar redan",
-    "Articles without feed" : "Artiklar utan flöde",
     "News" : "Nyheter",
     "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
     "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
