@@ -49,9 +49,9 @@ class ApiController extends BaseApiController
     }
 
     /**
-     * @return IUser
+     * @return IUser|null
      */
-    protected function getUser()
+    protected function getUser(): ?IUser
     {
         if ($this->userSession === null) {
             throw new NotLoggedInException();
