@@ -16,7 +16,6 @@
 namespace OCA\News\Controller;
 
 use Exception;
-use OCA\News\AppInfo\Application;
 use OCA\News\Service\Exceptions\ServiceConflictException;
 use OCA\News\Service\Exceptions\ServiceNotFoundException;
 use OCA\News\Service\FeedServiceV2;
@@ -25,10 +24,8 @@ use \OCP\IRequest;
 use \OCP\IUserSession;
 use \OCP\AppFramework\Http;
 
-use \OCA\News\Service\FeedService;
 use \OCA\News\Service\ItemService;
 use Psr\Log\LoggerInterface;
-use function GuzzleHttp\Psr7\uri_for;
 
 class FeedApiController extends ApiController
 {
@@ -45,33 +42,20 @@ class FeedApiController extends ApiController
      */
     private $feedService;
 
-    /**
-     * TODO: Remove
-     * @var FeedService
-     */
-    private $oldFeedService;
-
     /**
      * @var LoggerInterface
      */
     private $logger;
 
-    /**
-     * @var EntityApiSerializer
-     */
-    private $serializer;
-
     public function __construct(
         IRequest $request,
         ?IUserSession $userSession,
-        FeedService $oldFeedService,
         FeedServiceV2 $feedService,
         ItemService $oldItemService,
         LoggerInterface $logger
     ) {
         parent::__construct($request, $userSession);
         $this->feedService = $feedService;
-        $this->oldFeedService = $oldFeedService;
         $this->oldItemService = $oldItemService;
         $this->logger = $logger;
     }
@@ -122,6 +106,8 @@ class FeedApiController extends ApiController
             $feed = $this->feedService->create($this->getUserId(), $url, $folderId);
             $result = ['feeds' => $this->serialize($feed)];
 
+            $this->feedService->fetch($feed);
+
             try {
                 $result['newestItemId'] = $this->oldItemService->getNewestItemId($this->getUserId());
             } catch (ServiceNotFoundException $ex) {
@@ -189,11 +175,9 @@ class FeedApiController extends ApiController
         }
 
         try {
-            $this->oldFeedService->patch(
-                $feedId,
-                $this->getUserId(),
-                ['folderId' => $folderId]
-            );
+            $feed = $this->feedService->find($this->getUserId(), $feedId);
+            $feed->setFolderId($folderId);
+            $this->feedService->update($this->getUserId(), $feed);
         } catch (ServiceNotFoundException $ex) {
             return $this->error($ex, Http::STATUS_NOT_FOUND);
         }
@@ -215,11 +199,9 @@ class FeedApiController extends ApiController
     public function rename(int $feedId, string $feedTitle)
     {
         try {
-            $this->oldFeedService->patch(
-                $feedId,
-                $this->getUserId(),
-                ['title' => $feedTitle]
-            );
+            $feed = $this->feedService->find($this->getUserId(), $feedId);
+            $feed->setTitle($feedTitle);
+            $this->feedService->update($this->getUserId(), $feed);
         } catch (ServiceNotFoundException $ex) {
             return $this->error($ex, Http::STATUS_NOT_FOUND);
         }
