@@ -64,8 +64,6 @@ class Feed extends Entity implements IAPI, \JsonSerializable
     /** @var string|null */
     protected $lastModified = '0';
     /** @var string|null */
-    protected $httpEtag = null;
-    /** @var string|null */
     protected $location = null;
     /** @var int */
     protected $ordering = 0;
@@ -101,7 +99,6 @@ class Feed extends Entity implements IAPI, \JsonSerializable
         $this->addType('articlesPerUpdate', 'integer');
         $this->addType('httpLastModified', 'string');
         $this->addType('lastModified', 'string');
-        $this->addType('httpEtag', 'string');
         $this->addType('location', 'string');
         $this->addType('ordering', 'integer');
         $this->addType('fullTextEnabled', 'boolean');
@@ -177,14 +174,6 @@ class Feed extends Entity implements IAPI, \JsonSerializable
         return $this->fullTextEnabled;
     }
 
-    /**
-     * @return string|null
-     */
-    public function getHttpEtag(): ?string
-    {
-        return $this->httpEtag;
-    }
-
     /**
      * @return string|null
      */
@@ -453,19 +442,6 @@ class Feed extends Entity implements IAPI, \JsonSerializable
         return $this;
     }
 
-    /**
-     * @param string|null $httpEtag
-     */
-    public function setHttpEtag(?string $httpEtag = null): Feed
-    {
-        if ($this->httpEtag !== $httpEtag) {
-            $this->httpEtag = $httpEtag;
-            $this->markFieldUpdated('httpEtag');
-        }
-
-        return $this;
-    }
-
     /**
      * @param string|null $httpLastModified
      */
