@@ -13,10 +13,10 @@
 
 namespace OCA\News\Db;
 
-use Exception;
 use OCA\News\Utility\Time;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\Entity;
+use OCP\AppFramework\Db\Mapper;
 use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
@@ -27,20 +27,32 @@ use OCP\IDBConnection;
  * @package OCA\News\Db
  * @deprecated use ItemMapper
  */
-class ItemMapper extends NewsMapper
+class ItemMapper extends Mapper
 {
 
     const TABLE_NAME = 'news_items';
+    /**
+     * @var Time
+     */
+    private $time;
+
+    /**
+     * NewsMapper constructor.
+     *
+     * @param IDBConnection $db     Database connection
+     * @param Time          $time   Time class
+     */
     public function __construct(IDBConnection $db, Time $time)
     {
-        parent::__construct($db, $time, Item::class);
+        parent::__construct($db, static::TABLE_NAME, Item::class);
+        $this->time = $time;
     }
 
     private function makeSelectQuery(
-        $prependTo = '',
-        $oldestFirst = false,
-        $distinctFingerprint = false
-    ) {
+        string $prependTo = '',
+        bool $oldestFirst = false,
+        bool $distinctFingerprint = false
+    ): string {
         if ($oldestFirst) {
             $ordering = 'ASC';
         } else {
@@ -82,7 +94,7 @@ class ItemMapper extends NewsMapper
         return $sql;
     }
 
-    private function buildSearchQueryPart(array $search = [])
+    private function buildSearchQueryPart(array $search = []): string
     {
         return str_repeat('AND `items`.`search_index` LIKE ? ', count($search));
     }
@@ -107,7 +119,7 @@ class ItemMapper extends NewsMapper
     /**
      * @param int    $id
      * @param string $userId
-     * @return \OCA\News\Db\Item
+     * @return \OCA\News\Db\Item|Entity
      */
     public function find(string $userId, int $id)
     {
@@ -115,7 +127,7 @@ class ItemMapper extends NewsMapper
         return $this->findEntity($sql, [$userId, $id]);
     }
 
-    public function starredCount(string $userId)
+    public function starredCount(string $userId): int
     {
         $sql = 'SELECT COUNT(*) AS size FROM `*PREFIX*news_items` `items` ' .
             'JOIN `*PREFIX*news_feeds` `feeds` ' .
@@ -136,7 +148,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function readAll(int $highestItemId, $time, string $userId)
+    public function readAll(int $highestItemId, string $time, string $userId): void
     {
         $sql = 'UPDATE `*PREFIX*news_items` ' .
             'SET unread = ? ' .
@@ -151,7 +163,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function readFolder(?int $folderId, $highestItemId, $time, $userId)
+    public function readFolder(?int $folderId, int $highestItemId, string $time, string $userId): void
     {
         $folderWhere = is_null($folderId) ? 'IS' : '=';
         $sql = 'UPDATE `*PREFIX*news_items` ' .
@@ -169,7 +181,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function readFeed($feedId, $highestItemId, $time, $userId)
+    public function readFeed(int $feedId, int $highestItemId, string $time, string $userId): void
     {
         $sql = 'UPDATE `*PREFIX*news_items` ' .
             'SET unread = ? ' .
@@ -187,7 +199,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    private function getOperator($oldestFirst)
+    private function getOperator(bool $oldestFirst): string
     {
         if ($oldestFirst) {
             return '>';
@@ -197,7 +209,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function findAllNew($updatedSince, $type, $showAll, $userId)
+    public function findAllNew(int $updatedSince, int $type, bool $showAll, string $userId): array
     {
         $sql = $this->buildStatusQueryPart($showAll, $type);
 
@@ -208,12 +220,12 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function findAllNewFolder(?int $id, $updatedSince, $showAll, $userId)
+    public function findAllNewFolder(?int $id, int $updatedSince, bool $showAll, string $userId): array
     {
         $sql = $this->buildStatusQueryPart($showAll);
 
         $folderWhere = is_null($id) ? 'IS' : '=';
-        $sql .= "AND `feeds`.`folder_id` ${$folderWhere} ? " .
+        $sql .= "AND `feeds`.`folder_id` ${folderWhere} ? " .
             'AND `items`.`last_modified` >= ? ';
         $sql = $this->makeSelectQuery($sql);
         $params = [$userId, $id, $updatedSince];
@@ -221,7 +233,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function findAllNewFeed($id, $updatedSince, $showAll, $userId)
+    public function findAllNewFeed(?int $id, int $updatedSince, bool $showAll, string $userId): array
     {
         $sql = $this->buildStatusQueryPart($showAll);
 
@@ -233,7 +245,10 @@ class ItemMapper extends NewsMapper
     }
 
 
-    private function findEntitiesIgnoringNegativeLimit($sql, $params, $limit): array
+    /**
+     * @param (int|mixed|null)[] $params
+     */
+    private function findEntitiesIgnoringNegativeLimit(string $sql, array $params, int $limit): array
     {
         // ignore limit if negative to offer a way to return all feeds
         if ($limit >= 0) {
@@ -245,14 +260,14 @@ class ItemMapper extends NewsMapper
 
 
     public function findAllFeed(
-        $id,
-        $limit,
-        $offset,
-        $showAll,
-        $oldestFirst,
-        $userId,
-        $search = []
-    ) {
+        ?int $id,
+        int $limit,
+        int $offset,
+        bool $showAll,
+        bool $oldestFirst,
+        string $userId,
+        array $search = []
+    ): array {
         $params = [$userId];
         $params = array_merge($params, $this->buildLikeParameters($search));
         $params[] = $id;
@@ -266,20 +281,20 @@ class ItemMapper extends NewsMapper
                 $this->getOperator($oldestFirst) . ' ? ';
             $params[] = $offset;
         }
-        $sql = $this->makeSelectQuery($sql, $oldestFirst, $search);
+        $sql = $this->makeSelectQuery($sql, $oldestFirst);
         return $this->findEntitiesIgnoringNegativeLimit($sql, $params, $limit);
     }
 
 
     public function findAllFolder(
         ?int $id,
-        $limit,
-        $offset,
-        $showAll,
-        $oldestFirst,
-        $userId,
-        $search = []
-    ) {
+        int $limit,
+        int $offset,
+        bool $showAll,
+        bool $oldestFirst,
+        string $userId,
+        array $search = []
+    ): array {
         $params = [$userId];
         $params = array_merge($params, $this->buildLikeParameters($search));
         $params[] = $id;
@@ -293,19 +308,22 @@ class ItemMapper extends NewsMapper
             $sql .= 'AND `items`.`id` ' . $this->getOperator($oldestFirst) . ' ? ';
             $params[] = $offset;
         }
-        $sql = $this->makeSelectQuery($sql, $oldestFirst, $search);
+        $sql = $this->makeSelectQuery($sql, $oldestFirst);
         return $this->findEntitiesIgnoringNegativeLimit($sql, $params, $limit);
     }
 
 
+    /**
+     * @param string[] $search
+     */
     public function findAllItems(
-        $limit,
-        $offset,
-        $type,
-        $showAll,
-        $oldestFirst,
-        $userId,
-        $search = []
+        int $limit,
+        int $offset,
+        int $type,
+        bool $showAll,
+        bool $oldestFirst,
+        string $userId,
+        array $search = []
     ): array {
         $params = [$userId];
         $params = array_merge($params, $this->buildLikeParameters($search));
@@ -324,7 +342,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function findAllUnreadOrStarred($userId)
+    public function findAllUnreadOrStarred(string $userId): array
     {
         $params = [$userId, true, true];
         $sql = 'AND (`items`.`unread` = ? OR `items`.`starred` = ?) ';
@@ -332,7 +350,15 @@ class ItemMapper extends NewsMapper
         return $this->findEntities($sql, $params);
     }
 
-
+    /**
+     * @param $guidHash
+     * @param $feedId
+     * @param $userId
+     *
+     * @return Entity|Item
+     * @throws DoesNotExistException
+     * @throws MultipleObjectsReturnedException
+     */
     public function findByGuidHash($guidHash, $feedId, $userId)
     {
         $sql = $this->makeSelectQuery(
@@ -349,6 +375,8 @@ class ItemMapper extends NewsMapper
      * starred items
      *
      * @param int $threshold the number of items that should be deleted
+     *
+     * @return void
      */
     public function deleteReadOlderThanThreshold($threshold)
     {
@@ -396,7 +424,7 @@ class ItemMapper extends NewsMapper
     }
 
 
-    public function getNewestItemId($userId)
+    public function getNewestItemId(string $userId): int
     {
         $sql = 'SELECT MAX(`items`.`id`) AS `max_id` ' .
             'FROM `*PREFIX*news_items` `items` ' .
@@ -411,27 +439,15 @@ class ItemMapper extends NewsMapper
     }
 
 
-    /**
-     * Deletes all items of a user
-     *
-     * @param string $userId the name of the user
-     */
-    public function deleteUser($userId)
-    {
-        $sql = 'DELETE FROM `*PREFIX*news_items` ' .
-            'WHERE `feed_id` IN (' .
-            'SELECT `feeds`.`id` FROM `*PREFIX*news_feeds` `feeds` ' .
-            'WHERE `feeds`.`user_id` = ?' .
-            ')';
-
-        $this->execute($sql, [$userId]);
-    }
-
-
     /**
      * Returns a list of ids and userid of all items
+     *
+     * @param int|null $limit
+     * @param int|null $offset
+     *
+     * @return array|false
      */
-    public function findAllIds($limit = null, $offset = null)
+    public function findAllIds(?int $limit = null, ?int $offset = null)
     {
         $sql = 'SELECT `id` FROM `*PREFIX*news_items`';
         return $this->execute($sql, [], $limit, $offset)->fetchAll();
@@ -439,8 +455,10 @@ class ItemMapper extends NewsMapper
 
     /**
      * Update search indices of all items
+     *
+     * @return void
      */
-    public function updateSearchIndices()
+    public function updateSearchIndices(): void
     {
         // update indices in steps to prevent memory issues on larger systems
         $step = 1000;  // update 1000 items at a time
@@ -456,7 +474,7 @@ class ItemMapper extends NewsMapper
         }
     }
 
-    private function updateSearchIndex(array $items = [])
+    private function updateSearchIndex(array $items = []): void
     {
         foreach ($items as $row) {
             $sql = 'SELECT * FROM `*PREFIX*news_items` WHERE `id` = ?';
@@ -467,7 +485,10 @@ class ItemMapper extends NewsMapper
         }
     }
 
-    public function readItem($itemId, $isRead, $lastModified, $userId)
+    /**
+     * @return void
+     */
+    public function readItem(int $itemId, bool $isRead, string $lastModified, string $userId)
     {
         $item = $this->find($userId, $itemId);
 
@@ -492,29 +513,74 @@ class ItemMapper extends NewsMapper
         }
     }
 
-    /**
-     * NO-OP
-     *
-     * @param string $userId
-     *
-     * @return array
-     */
-    public function findAllFromUser(string $userId): array
+    public function update(Entity $entity): Entity
     {
-        return [];
+        $entity->setLastModified($this->time->getMicroTime());
+        return parent::update($entity);
     }
 
-    public function findFromUser(string $userId, int $id): Entity
+    public function insert(Entity $entity): Entity
     {
-        return $this->find($id, $userId);
+        $entity->setLastModified($this->time->getMicroTime());
+        return parent::insert($entity);
     }
 
     /**
-     * NO-OP
-     * @return array
+     * Remove deleted items.
+     *
+     * @return void
      */
-    public function findAll(): array
+    public function purgeDeleted(): void
     {
-        return [];
+        $builder = $this->db->getQueryBuilder();
+        $builder->delete($this->tableName)
+            ->where('deleted_at != 0')
+            ->execute();
+    }
+    /**
+     * Performs a SELECT query with all arguments appended to the WHERE clause
+     * The SELECT will be performed on the current table and takes the entity
+     * that is related for transforming the properties into column names
+     *
+     * Important: This method does not filter marked as deleted rows!
+     *
+     * @param array $search an assoc array from property to filter value
+     * @param int|null $limit  Output limit
+     * @param int|null $offset Output offset
+     *
+     * @depreacted Legacy function
+     *
+     * @return Entity[]
+     */
+    public function where(array $search = [], ?int $limit = null, ?int $offset = null)
+    {
+        $entity = new $this->entityClass();
+
+        // turn keys into sql query filter, e.g. feedId -> feed_id = :feedId
+        $filter = array_map(
+            function ($property) use ($entity) {
+                // check if the property actually exists on the entity to prevent
+                // accidental Sql injection
+                if (!property_exists($entity, $property)) {
+                    $msg = 'Property ' . $property . ' does not exist on '
+                        . $this->entityClass;
+                    throw new \BadFunctionCallException($msg);
+                }
+
+                $column = $entity->propertyToColumn($property);
+                return $column . ' = :' . $property;
+            },
+            array_keys($search)
+        );
+
+        $andStatement = implode(' AND ', $filter);
+
+        $sql = 'SELECT * FROM `' . $this->getTableName() . '`';
+
+        if (count($search) > 0) {
+            $sql .= 'WHERE ' . $andStatement;
+        }
+
+        return $this->findEntities($sql, $search, $limit, $offset);
     }
 }
