@@ -18,9 +18,7 @@ use OCA\News\Db\Folder;
 use OCA\News\Db\FolderMapperV2;
 use OCA\News\Service\Exceptions\ServiceConflictException;
 use OCA\News\Service\Exceptions\ServiceNotFoundException;
-use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\Entity;
-use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use Psr\Log\LoggerInterface;
 
 /**
@@ -35,7 +33,7 @@ class FolderServiceV2 extends Service
      */
     private $feedService;
     /**
-     * @var FeedServiceV2
+     * @var TimeFactory
      */
     private $timeFactory;
 
@@ -63,28 +61,6 @@ class FolderServiceV2 extends Service
         return $this->mapper->findAllFromUser($userId, $params);
     }
 
-    /**
-     * Finds a folder of a user
-     *
-     * @param string   $userId   The name/ID of the user
-     * @param int|null $folderId ID of the folder
-     *
-     * @return Folder
-     *
-     * @throws ServiceConflictException
-     * @throws ServiceNotFoundException
-     */
-    public function findForUser(string $userId, ?int $folderId): Entity
-    {
-        try {
-            return $this->mapper->findFromUser($userId, $folderId);
-        } catch (DoesNotExistException $e) {
-            throw new ServiceNotFoundException('Folder not found');
-        } catch (MultipleObjectsReturnedException $e) {
-            throw new ServiceConflictException('Multiple folders found');
-        }
-    }
-
     /**
      * Find all folders and it's feeds.
      *
@@ -133,30 +109,15 @@ class FolderServiceV2 extends Service
         return $this->mapper->insert($folder);
     }
 
-    /**
-     * Delete a feed.
-     *
-     * @param string $userId   Folder owner
-     * @param int    $folderId Folder ID
-     *
-     * @return Folder
-     * @throws ServiceConflictException
-     * @throws ServiceNotFoundException
-     */
-    public function delete(string $userId, int $folderId): Entity
-    {
-        $folder = $this->findForUser($userId, $folderId);
-
-        return $this->mapper->delete($folder);
-    }
-
     /**
      * Purge all deleted folders.
      *
      * @param string|null $userID       The user to purge
      * @param int|null    $minTimestamp The timestamp to purge from
+     *
+     * @return void
      */
-    public function purgeDeleted(?string $userID, ?int $minTimestamp)
+    public function purgeDeleted(?string $userID, ?int $minTimestamp): void
     {
         $this->mapper->purgeDeleted($userID, $minTimestamp);
     }
@@ -174,8 +135,9 @@ class FolderServiceV2 extends Service
      */
     public function rename(string $userId, int $folderId, string $newName): Entity
     {
-        $folder = $this->findForUser($userId, $folderId);
+        $folder = $this->find($userId, $folderId);
         $folder->setName($newName);
+
         return $this->mapper->update($folder);
     }
 
@@ -192,7 +154,7 @@ class FolderServiceV2 extends Service
      */
     public function markDelete(string $userId, int $folderId, bool $mark): Entity
     {
-        $folder = $this->findForUser($userId, $folderId);
+        $folder = $this->find($userId, $folderId);
         $time = $mark ? $this->timeFactory->getTime() : 0;
         $folder->setDeletedAt($time);
 
@@ -212,21 +174,8 @@ class FolderServiceV2 extends Service
      */
     public function open(string $userId, ?int $folderId, bool $open): Entity
     {
-        $folder = $this->findForUser($userId, $folderId);
+        $folder = $this->find($userId, $folderId);
         $folder->setOpened($open);
         return $this->mapper->update($folder);
     }
-
-    /**
-     * Delete all folders of a user
-     *
-     * @param string $userId User ID/name
-     */
-    public function deleteUser(string $userId): void
-    {
-        $folders = $this->findAllForUser($userId);
-        foreach ($folders as $folder) {
-            $this->mapper->delete($folder);
-        }
-    }
 }
