@@ -16,6 +16,7 @@ use OCA\News\AppInfo\Application;
 use OCA\News\Db\Item;
 use OCA\News\Db\ItemMapperV2;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\AppFramework\Db\Entity;
 use OCP\IConfig;
 use Psr\Log\LoggerInterface;
 
@@ -76,8 +77,10 @@ class ItemServiceV2 extends Service
      * Insert an item or update.
      *
      * @param Item $item
+     *
+     * @return Entity|Item The updated/inserted item
      */
-    public function insertOrUpdate(Item $item)
+    public function insertOrUpdate(Item $item): Entity
     {
         try {
             $db_item = $this->mapper->findByGuidHash($item->getFeedId(), $item->getGuidHash());
@@ -94,30 +97,49 @@ class ItemServiceV2 extends Service
                 $item->resetUpdatedFields();
             }
 
-            $this->mapper->update($item);
+            return $this->mapper->update($item);
         } catch (DoesNotExistException $exception) {
-            $this->mapper->insert($item);
+            return $this->mapper->insert($item);
         }
     }
 
+    /**
+     * @param int $feedId
+     *
+     * @return array
+     */
     public function findAllForFeed(int $feedId): array
     {
         return $this->mapper->findAllForFeed($feedId);
     }
 
-    public function purgeOverThreshold(int $threshold = null)
+    /**
+     * @param int|null $threshold
+     * @param bool     $removeUnread
+     *
+     * @return int|null Amount of deleted items or null if not applicable
+     */
+    public function purgeOverThreshold(int $threshold = null, bool $removeUnread = false): ?int
     {
-
-        $threshold = (int) $threshold ?? $this->config->getAppValue(
+        $threshold = (int) ($threshold ?? $this->config->getAppValue(
             Application::NAME,
             'autoPurgeCount',
             Application::DEFAULT_SETTINGS['autoPurgeCount']
-        );
+        ));
 
-        if ($threshold === 0) {
-            return '';
+        if ($threshold <= 0) {
+            return null;
         }
 
-        return $this->mapper->deleteOverThreshold($threshold);
+        return $this->mapper->deleteOverThreshold($threshold, $removeUnread);
+    }
+
+    /**
+     * @param int    $feedId
+     * @param string $guidHash
+     */
+    public function findForGuidHash(int $feedId, string $guidHash)
+    {
+        return $this->mapper->findByGuidHash($feedId, $guidHash);
     }
 }
